@@ -7,18 +7,19 @@ import pandas as pd
 from PyQt5 import QtCore, QtGui, QtWidgets
 from PyQt5.QtCore import Qt
 
-from pandasgui.store import Store, PandasGuiDataFrame
+from pandasgui.store import PandasGuiStore, PandasGuiDataFrameStore
 import pandasgui
 
 import logging
+
 logger = logging.getLogger(__name__)
 
 
 class DataFrameViewer(QtWidgets.QWidget):
-    def __init__(self, pgdf: PandasGuiDataFrame):
+    def __init__(self, pgdf: PandasGuiDataFrameStore):
         super().__init__()
 
-        pgdf = PandasGuiDataFrame.cast(pgdf)
+        pgdf = PandasGuiDataFrameStore.cast(pgdf)
         pgdf.dataframe_viewer = self
         self.pgdf = pgdf
 
@@ -54,44 +55,41 @@ class DataFrameViewer(QtWidgets.QWidget):
         # Disable scrolling on the headers. Even though the scrollbars are hidden, scrolling by dragging desyncs them
         self.indexHeader.horizontalScrollBar().valueChanged.connect(lambda: None)
 
-        # Add items to 4x4 grid layout
-        self.gridLayout.addWidget(self.columnHeader, 0, 1, 1, 2)
-        self.gridLayout.addWidget(self.indexHeader, 1, 0, 2, 2)
-        self.gridLayout.addWidget(self.dataView, 2, 2, 1, 1)
-        self.gridLayout.addWidget(self.dataView.horizontalScrollBar(), 3, 2, 1, 1)
-        self.gridLayout.addWidget(self.dataView.verticalScrollBar(), 2, 3, 1, 1)
-        self.gridLayout.addWidget(self.columnHeaderNames, 0, 3, 1, 1)
-        self.gridLayout.addWidget(self.indexHeaderNames, 0, 0, 1, 1, Qt.AlignBottom)
+        class CornerWidget(QtWidgets.QWidget):
+            def __init__(self):
+                super().__init__()
+                # https://stackoverflow.com/questions/32313469/stylesheet-in-pyside-not-working
+                self.setAttribute(QtCore.Qt.WA_StyledBackground)
+
+        self.corner_widget = CornerWidget()
+        self.corner_widget.setSizePolicy(QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding,
+                                                               QtWidgets.QSizePolicy.Expanding))
+        # Add items to grid layout
+        self.gridLayout.addWidget(self.corner_widget, 0, 0)
+        self.gridLayout.addWidget(self.columnHeader, 0, 1, 2, 2)
+        self.gridLayout.addWidget(self.columnHeaderNames, 0, 3, 2, 1)
+        self.gridLayout.addWidget(self.indexHeader, 2, 0, 2, 2)
+        self.gridLayout.addWidget(self.indexHeaderNames, 1, 0, 1, 1, Qt.AlignBottom)
+        self.gridLayout.addWidget(self.dataView, 3, 2, 1, 1)
+        self.gridLayout.addWidget(self.dataView.horizontalScrollBar(), 4, 2, 1, 1)
+        self.gridLayout.addWidget(self.dataView.verticalScrollBar(), 3, 3, 1, 1)
 
         # These expand when the window is enlarged instead of having the grid squares spread out
         self.gridLayout.setColumnStretch(4, 1)
-        self.gridLayout.setRowStretch(4, 1)
-
-        self.gridLayout.addItem(QtWidgets.QSpacerItem(0, 0,
-                                                      QtWidgets.QSizePolicy.Expanding,
-                                                      QtWidgets.QSizePolicy.Expanding), 0, 0, 1, 1, )
+        self.gridLayout.setRowStretch(5, 1)
+        #
+        # self.gridLayout.addItem(QtWidgets.QSpacerItem(0, 0,
+        #                                               QtWidgets.QSizePolicy.Expanding,
+        #                                               QtWidgets.QSizePolicy.Expanding), 0, 0, 1, 1, )
 
         self.set_styles()
         self.indexHeader.setSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Maximum)
         self.columnHeader.setSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.MinimumExpanding)
 
     def set_styles(self):
-
         for item in [self.dataView, self.columnHeader, self.indexHeader, self.indexHeaderNames, self.columnHeaderNames]:
             item.setContentsMargins(0, 0, 0, 0)
-            item.setStyleSheet(item.styleSheet() + "QTableView{border: 0px solid black;}")
-            item.setItemDelegate(NoFocusDelegate())
-
-        # Style table data cells
-        # self.dataView.setStyleSheet(self.dataView.styleSheet() + "")
-
-        # # Style header cells
-        # for header in [self.columnHeader, self.indexHeader]:
-        #     header.setStyleSheet(header.styleSheet() + ";")
-
-        # # Style header level name labels
-        # for header_label in [self.indexHeaderNames, self.columnHeaderNames]:
-        #     header_label.setStyleSheet(header_label.styleSheet() + "")
+            # item.setItemDelegate(NoFocusDelegate())
 
     def __reduce__(self):
         # This is so dataclasses.asdict doesn't complain about this being unpicklable
@@ -187,17 +185,90 @@ class DataFrameViewer(QtWidgets.QWidget):
         self.indexHeader.updateGeometry()
 
     def keyPressEvent(self, event):
+        # Disabling this and moving hotkeys to main GUI
+        if self.pgdf.gui is not None:
+            super(DataFrameViewer, self).keyPressEvent(event)
 
         QtWidgets.QWidget.keyPressEvent(self, event)
+        mods = event.modifiers()
 
-        if event.matches(QtGui.QKeySequence.Copy):
-            self.dataView.copy()
+        # Ctrl+C
+        if event.key() == Qt.Key_C and (mods & Qt.ControlModifier):
+            self.copy()
+        # Ctrl+Shift+C
+        if event.key() == Qt.Key_C and (mods & Qt.ShiftModifier) and (mods & Qt.ControlModifier):
+            self.copy(header=True)
         if event.matches(QtGui.QKeySequence.Paste):
-            self.dataView.paste()
-        # if event.key() == Qt.Key_P and (event.modifiers() & Qt.ControlModifier):
-        #     print("Ctrl + P")
-        # if event.key() == Qt.Key_D and (event.modifiers() & Qt.ControlModifier):
-        #     print("Ctrl + D")
+            self.paste()
+        if event.key() == Qt.Key_P and (mods & Qt.ControlModifier):
+            pass
+        if event.key() == Qt.Key_D and (mods & Qt.ControlModifier):
+            pass
+
+    def copy(self, header=False):
+        """
+        Copy the selected cells to clipboard in an Excel-pasteable format
+        """
+        # Get the bounds using the top left and bottom right selected cells
+
+        # Copy from data, columns, or index depending which has focus
+        if header or self.dataView.hasFocus():
+            indexes = self.dataView.selectionModel().selection().indexes()
+            rows = [ix.row() for ix in indexes]
+            cols = [ix.column() for ix in indexes]
+
+            temp_df = self.pgdf.df
+            df = temp_df.iloc[min(rows): max(rows) + 1, min(cols): max(cols) + 1]
+
+        elif self.indexHeader.hasFocus():
+            indexes = self.indexHeader.selectionModel().selection().indexes()
+            rows = [ix.row() for ix in indexes]
+            cols = [ix.column() for ix in indexes]
+
+            temp_df = self.pgdf.df.index.to_frame()
+            df = temp_df.iloc[min(rows): max(rows) + 1, min(cols): max(cols) + 1]
+
+        elif self.columnHeader.hasFocus():
+            indexes = self.columnHeader.selectionModel().selection().indexes()
+            rows = [ix.row() for ix in indexes]
+            cols = [ix.column() for ix in indexes]
+
+            # Column header should be horizontal so we transpose
+            temp_df = self.pgdf.df.columns.to_frame().transpose()
+            df = temp_df.iloc[min(rows): max(rows) + 1, min(cols): max(cols) + 1]
+        else:
+            return
+
+        # Special case for single-cell copy since df.to_clipboard appends extra newline
+        if df.shape == (1, 1):
+            clipboard = QtWidgets.QApplication.instance().clipboard()
+            value = str(df.iloc[0, 0])
+            clipboard.setText(value)
+        else:
+            # If I try to use Pyperclip without starting new thread large selections give access denied error
+            threading.Thread(target=lambda df: df.to_clipboard(index=header, header=header), args=(df,)).start()
+
+    def paste(self):
+        df_to_paste = pd.read_clipboard(sep=',|\t', header=None)
+
+        # Get the bounds using the top left and bottom right selected cells
+        indexes = self.dataView.selectionModel().selection().indexes()
+        rows = [ix.row() for ix in indexes]
+        cols = [ix.column() for ix in indexes]
+
+        self.pgdf.paste_data(min(rows), min(cols), df_to_paste)
+
+        # Select the range of cells that were pasted
+        self.dataView.selectionModel().clearSelection()
+        temp = self.dataView.selectionMode()
+        self.dataView.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
+
+        for i in range(df_to_paste.shape[0]):
+            for j in range(df_to_paste.shape[1]):
+                self.dataView.selectionModel().select(self.dataView.model().index(min(rows) + i, min(cols) + j),
+                                                      QtCore.QItemSelectionModel.Select)
+
+        self.dataView.setSelectionMode(temp)
 
 
 # Remove dotted border on cell focus.  https://stackoverflow.com/a/55252650/3620725
@@ -220,17 +291,17 @@ class DataTableModel(QtCore.QAbstractTableModel):
 
     def __init__(self, parent):
         super().__init__(parent)
-        self.pgdf: PandasGuiDataFrame = parent.pgdf
+        self.pgdf: PandasGuiDataFrameStore = parent.pgdf
 
     def headerData(self, section, orientation, role=None):
         # Headers for DataTableView are hidden. Header data is shown in HeaderView
         pass
 
     def columnCount(self, parent=None):
-        return self.pgdf.dataframe.columns.shape[0]
+        return self.pgdf.df.columns.shape[0]
 
     def rowCount(self, parent=None):
-        return len(self.pgdf.dataframe)
+        return len(self.pgdf.df)
 
     # Returns the data from the DataFrame
     def data(self, index, role=QtCore.Qt.DisplayRole):
@@ -241,7 +312,7 @@ class DataTableModel(QtCore.QAbstractTableModel):
         ):
             row = index.row()
             col = index.column()
-            cell = self.pgdf.dataframe.iloc[row, col]
+            cell = self.pgdf.df.iloc[row, col]
 
             # Need to check type since a cell might contain a list or Series, then .isna returns a Series not a bool
             cell_is_na = pd.isna(cell)
@@ -258,7 +329,7 @@ class DataTableModel(QtCore.QAbstractTableModel):
         elif role == QtCore.Qt.ToolTipRole:
             row = index.row()
             col = index.column()
-            cell = self.pgdf.dataframe.iloc[row, col]
+            cell = self.pgdf.df.iloc[row, col]
 
             return str(cell)
 
@@ -287,7 +358,7 @@ class DataTableView(QtWidgets.QTableView):
 
     def __init__(self, parent):
         super().__init__(parent)
-        self.pgdf: PandasGuiDataFrame = parent.pgdf
+        self.pgdf: PandasGuiDataFrameStore = parent.pgdf
 
         # Create and set model
         model = DataTableModel(parent)
@@ -335,49 +406,6 @@ class DataTableView(QtWidgets.QTableView):
                 | QtCore.QItemSelectionModel.ClearAndSelect,
             )
 
-    def copy(self):
-        """
-        Copy the selected cells to clipboard in an Excel-pasteable format
-        """
-
-        # Get the bounds using the top left and bottom right selected cells
-        indexes = self.selectionModel().selection().indexes()
-        rows = [ix.row() for ix in indexes]
-        cols = [ix.column() for ix in indexes]
-
-        df = self.pgdf.dataframe.iloc[min(rows): max(rows) + 1, min(cols): max(cols) + 1]
-
-        # Special case for single-cell copy since df.to_clipboard appends extra newline
-        if df.shape == (1, 1):
-            clipboard = QtWidgets.QApplication.instance().clipboard()
-            value = str(df.iloc[0, 0])
-            clipboard.setText(value)
-        else:
-            # If I try to use Pyperclip without starting new thread large selections give access denied error
-            threading.Thread(target=lambda df: df.to_clipboard(index=False, header=False), args=(df,)).start()
-
-    def paste(self):
-        df_to_paste = pd.read_clipboard(sep=',|\t', header=None)
-
-        # Get the bounds using the top left and bottom right selected cells
-        indexes = self.selectionModel().selection().indexes()
-        rows = [ix.row() for ix in indexes]
-        cols = [ix.column() for ix in indexes]
-
-        self.pgdf.paste_data(min(rows), min(cols), df_to_paste)
-
-        # Select the range of cells that were pasted
-        self.selectionModel().clearSelection()
-        temp = self.selectionMode()
-        self.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
-
-        for i in range(df_to_paste.shape[0]):
-            for j in range(df_to_paste.shape[1]):
-                self.selectionModel().select(self.model().index(min(rows) + i, min(cols) + j),
-                                             QtCore.QItemSelectionModel.Select)
-
-        self.setSelectionMode(temp)
-
     def sizeHint(self):
         # Set width and height based on number of columns in model
         # Width
@@ -400,19 +428,19 @@ class HeaderModel(QtCore.QAbstractTableModel):
     def __init__(self, parent, orientation):
         super().__init__(parent)
         self.orientation = orientation
-        self.pgdf: PandasGuiDataFrame = parent.pgdf
+        self.pgdf: PandasGuiDataFrameStore = parent.pgdf
 
     def columnCount(self, parent=None):
         if self.orientation == Qt.Horizontal:
-            return self.pgdf.dataframe.columns.shape[0]
+            return self.pgdf.df.columns.shape[0]
         else:  # Vertical
-            return self.pgdf.dataframe.index.nlevels
+            return self.pgdf.df.index.nlevels
 
     def rowCount(self, parent=None):
         if self.orientation == Qt.Horizontal:
-            return self.pgdf.dataframe.columns.nlevels
+            return self.pgdf.df.columns.nlevels
         elif self.orientation == Qt.Vertical:
-            return self.pgdf.dataframe.index.shape[0]
+            return self.pgdf.df.index.shape[0]
 
     def data(self, index, role=QtCore.Qt.DisplayRole):
         row = index.row()
@@ -422,23 +450,23 @@ class HeaderModel(QtCore.QAbstractTableModel):
 
             if self.orientation == Qt.Horizontal:
 
-                if isinstance(self.pgdf.dataframe.columns, pd.MultiIndex):
-                    return str(self.pgdf.dataframe.columns.values[col][row])
+                if isinstance(self.pgdf.df.columns, pd.MultiIndex):
+                    return str(self.pgdf.df.columns[col][row])
                 else:
-                    return str(self.pgdf.dataframe.columns.values[col])
+                    return str(self.pgdf.df.columns[col])
 
             elif self.orientation == Qt.Vertical:
 
-                if isinstance(self.pgdf.dataframe.index, pd.MultiIndex):
-                    return str(self.pgdf.dataframe.index.values[row][col])
+                if isinstance(self.pgdf.df.index, pd.MultiIndex):
+                    return str(self.pgdf.df.index[row][col])
                 else:
-                    return str(self.pgdf.dataframe.index.values[row])
+                    return str(self.pgdf.df.index[row])
 
         if role == QtCore.Qt.DecorationRole:
             if self.pgdf.sort_is_ascending:
-                icon = QtGui.QIcon(os.path.join(pandasgui.__path__[0], "resources/images/sort-ascending.png"))
+                icon = QtGui.QIcon(os.path.join(pandasgui.__path__[0], "resources/images/sort-ascending.svg"))
             else:
-                icon = QtGui.QIcon(os.path.join(pandasgui.__path__[0], "resources/images/sort-descending.png"))
+                icon = QtGui.QIcon(os.path.join(pandasgui.__path__[0], "resources/images/sort-descending.svg"))
 
             if col == self.pgdf.column_sorted and row == self.rowCount() - 1 and self.orientation == Qt.Horizontal:
                 return icon
@@ -448,15 +476,15 @@ class HeaderModel(QtCore.QAbstractTableModel):
         if role in [QtCore.Qt.DisplayRole, QtCore.Qt.ToolTipRole]:
 
             if self.orientation == Qt.Horizontal and orientation == Qt.Vertical:
-                if isinstance(self.pgdf.dataframe.columns, pd.MultiIndex):
-                    return str(self.pgdf.dataframe.columns.names[section])
+                if isinstance(self.pgdf.df.columns, pd.MultiIndex):
+                    return str(self.pgdf.df.columns.names[section])
                 else:
-                    return str(self.pgdf.dataframe.columns.name)
+                    return str(self.pgdf.df.columns.name)
             elif self.orientation == Qt.Vertical and orientation == Qt.Horizontal:
-                if isinstance(self.pgdf.dataframe.index, pd.MultiIndex):
-                    return str(self.pgdf.dataframe.index.names[section])
+                if isinstance(self.pgdf.df.index, pd.MultiIndex):
+                    return str(self.pgdf.df.index.names[section])
                 else:
-                    return str(self.pgdf.dataframe.index.name)
+                    return str(self.pgdf.df.index.name)
             else:
                 return None  # These cells should be hidden anyways
 
@@ -468,7 +496,8 @@ class HeaderView(QtWidgets.QTableView):
 
     def __init__(self, parent: DataFrameViewer, orientation):
         super().__init__(parent)
-        self.pgdf: PandasGuiDataFrame = parent.pgdf
+        self.pgdf: PandasGuiDataFrameStore = parent.pgdf
+        self.setProperty('orientation', 'horizontal' if orientation == 1 else 'vertical')  # Used in stylesheet
 
         # Setup
         self.orientation = orientation
@@ -512,7 +541,7 @@ class HeaderView(QtWidgets.QTableView):
         # Set initial size
         self.resize(self.sizeHint())
 
-    def mousePressEvent(self, event):
+    def mouseDoubleClickEvent(self, event):
         point = event.pos()
         ix = self.indexAt(point)
         if event.button() == QtCore.Qt.LeftButton:
@@ -521,14 +550,20 @@ class HeaderView(QtWidgets.QTableView):
                 self.pgdf.sort_column(ix.column())
             else:
                 self.on_selectionChanged()
-        elif event.button() == QtCore.Qt.RightButton:
-            pass
+        else:
+            super().mouseDoubleClickEvent(event)
+
+    def mousePressEvent(self, event):
+        point = event.pos()
+        ix = self.indexAt(point)
+        if event.button() == QtCore.Qt.RightButton:
             menu = QtWidgets.QMenu(self)
             action = QtWidgets.QAction("Sort")
             action.triggered.connect(lambda: self.pgdf.sort_column(ix.column()))
             menu.addAction(action)
             menu.exec_(self.mapToGlobal(point))
-        super().mousePressEvent(event)
+        else:
+            super().mousePressEvent(event)
 
     # Header
     def on_selectionChanged(self):
@@ -548,7 +583,7 @@ class HeaderView(QtWidgets.QTableView):
                 selection = self.selectionModel().selection()
 
                 # Removes the higher levels so that only the lowest level of the header affects the data table selection
-                last_row_ix = self.pgdf.dataframe.columns.nlevels - 1
+                last_row_ix = self.pgdf.df.columns.nlevels - 1
                 last_col_ix = self.model().columnCount() - 1
                 higher_levels = QtCore.QItemSelection(
                     self.model().index(0, 0),
@@ -566,7 +601,7 @@ class HeaderView(QtWidgets.QTableView):
                 selection = self.selectionModel().selection()
 
                 last_row_ix = self.model().rowCount() - 1
-                last_col_ix = self.pgdf.dataframe.index.nlevels - 1
+                last_col_ix = self.pgdf.df.index.nlevels - 1
                 higher_levels = QtCore.QItemSelection(
                     self.model().index(0, 0),
                     self.model().index(last_row_ix, last_col_ix - 1),
@@ -584,11 +619,15 @@ class HeaderView(QtWidgets.QTableView):
     # Take the current set of selected cells and make it so that any spanning cell above a selected cell is selected too
     # This should happen after every selection change
     def selectAbove(self):
+
+        # Disabling this to allow selecting specific cells in headers
+        return
+
         if self.orientation == Qt.Horizontal:
-            if self.pgdf.dataframe.columns.nlevels == 1:
+            if self.pgdf.df.columns.nlevels == 1:
                 return
         else:
-            if self.pgdf.dataframe.index.nlevels == 1:
+            if self.pgdf.df.index.nlevels == 1:
                 return
 
         for ix in self.selectedIndexes():
@@ -630,7 +669,7 @@ class HeaderView(QtWidgets.QTableView):
     # This sets spans to group together adjacent cells with the same values
     def set_spans(self):
 
-        df = self.pgdf.dataframe
+        df = self.pgdf.df
         self.clearSpans()
         # Find spans for horizontal HeaderView
         if self.orientation == Qt.Horizontal:
@@ -845,17 +884,17 @@ class HeaderNamesModel(QtCore.QAbstractTableModel):
     def __init__(self, parent, orientation):
         super().__init__(parent)
         self.orientation = orientation
-        self.pgdf: PandasGuiDataFrame = parent.pgdf
+        self.pgdf: PandasGuiDataFrameStore = parent.pgdf
 
     def columnCount(self, parent=None):
         if self.orientation == Qt.Horizontal:
             return 1
         elif self.orientation == Qt.Vertical:
-            return self.pgdf.dataframe.index.nlevels
+            return self.pgdf.df.index.nlevels
 
     def rowCount(self, parent=None):
         if self.orientation == Qt.Horizontal:
-            return self.pgdf.dataframe.columns.nlevels
+            return self.pgdf.df.columns.nlevels
         elif self.orientation == Qt.Vertical:
             return 1
 
@@ -866,22 +905,22 @@ class HeaderNamesModel(QtCore.QAbstractTableModel):
         if role == QtCore.Qt.DisplayRole or role == QtCore.Qt.ToolTipRole:
 
             if self.orientation == Qt.Horizontal:
-                val = self.pgdf.dataframe.columns.names[row]
+                val = self.pgdf.df.columns.names[row]
                 if val is None:
                     val = ""
                 return str(val)
 
             elif self.orientation == Qt.Vertical:
-                val = self.pgdf.dataframe.index.names[col]
+                val = self.pgdf.df.index.names[col]
                 if val is None:
                     val = "index"
                 return str(val)
 
         if role == QtCore.Qt.DecorationRole:
             if self.pgdf.sort_is_ascending:
-                icon = QtGui.QIcon(os.path.join(pandasgui.__path__[0], "resources/images/sort-ascending.png"))
+                icon = QtGui.QIcon(os.path.join(pandasgui.__path__[0], "resources/images/sort-ascending.svg"))
             else:
-                icon = QtGui.QIcon(os.path.join(pandasgui.__path__[0], "resources/images/sort-descending.png"))
+                icon = QtGui.QIcon(os.path.join(pandasgui.__path__[0], "resources/images/sort-descending.svg"))
 
             if col == self.pgdf.index_sorted and self.orientation == Qt.Vertical:
                 return icon
@@ -890,14 +929,13 @@ class HeaderNamesModel(QtCore.QAbstractTableModel):
 class HeaderNamesView(QtWidgets.QTableView):
     def __init__(self, parent: DataFrameViewer, orientation):
         super().__init__(parent)
-        self.pgdf: PandasGuiDataFrame = parent.pgdf
+        self.pgdf: PandasGuiDataFrameStore = parent.pgdf
+        self.setProperty('orientation', 'horizontal' if orientation == 1 else 'vertical')  # Used in stylesheet
 
         # Setup
         self.orientation = orientation
         self.setModel(HeaderNamesModel(parent, orientation))
 
-        self.clicked.connect(self.on_clicked)
-
         self.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
 
@@ -914,10 +952,14 @@ class HeaderNamesView(QtWidgets.QTableView):
         self.setFont(font)
         self.init_size()
 
-    def on_clicked(self, ix: QtCore.QModelIndex):
-        # When the index header name is clicked, sort the index by that level
-        if self.orientation == Qt.Vertical:
-            self.pgdf.sort_index(ix.column())
+    def mouseDoubleClickEvent(self, event):
+        point = event.pos()
+        ix = self.indexAt(point)
+        if event.button() == QtCore.Qt.LeftButton:
+            if self.orientation == Qt.Vertical:
+                self.pgdf.sort_index(ix.column())
+        else:
+            super().mouseDoubleClickEvent(event)
 
     def init_size(self):
         # Match vertical header name widths to vertical header
@@ -931,7 +973,7 @@ class HeaderNamesView(QtWidgets.QTableView):
             height = self.parent().columnHeader.sizeHint().height()
         else:  # Vertical
             width = self.parent().indexHeader.sizeHint().width()
-            height = self.rowHeight(0)
+            height = self.rowHeight(0) + 2
 
         return QtCore.QSize(width, height)
 
@@ -943,7 +985,7 @@ class HeaderNamesView(QtWidgets.QTableView):
 
     def columnWidth(self, column: int) -> int:
         if self.orientation == Qt.Horizontal:
-            if all(name is None for name in self.pgdf.dataframe.columns.names):
+            if all(name is None for name in self.pgdf.df.columns.names):
                 return 0
             else:
                 return super().columnWidth(column)
@@ -972,9 +1014,9 @@ class TrackingSpacer(QtWidgets.QFrame):
 # Examples
 if __name__ == "__main__":
     app = QtWidgets.QApplication(sys.argv)
-    from pandasgui.datasets import pokemon, mi_manufacturing
+    from pandasgui.datasets import pokemon, mi_manufacturing, multiindex
 
-    view = DataFrameViewer(pokemon)
+    view = DataFrameViewer(multiindex)
 
     view.show()
     app.exec_()
